@@ -1,5 +1,6 @@
 import re
 from typing import Any
+from typing import Dict
 
 from pythogen import models
 from pythogen.parsers.references import RefResolver
@@ -7,17 +8,17 @@ from pythogen.parsers.schemas import SchemaParser
 
 
 class ParameterParser:
-    def __init__(self, ref_resolver: RefResolver, schema_parser: SchemaParser, openapi_data: dict[str, Any]) -> None:
+    def __init__(self, ref_resolver: RefResolver, schema_parser: SchemaParser, openapi_data: Dict[str, Any]) -> None:
         self._openapi_data = openapi_data
         self._ref_resolver = ref_resolver
         self._schema_parser = schema_parser
 
-    def parse_collections(self) -> dict[str, models.ParameterObject]:
+    def parse_collections(self) -> Dict[str, models.ParameterObject]:
         parameters = self._openapi_data["components"].get('parameters', {})
         result = {}
         for parameter_id, parameter_data in parameters.items():
-            if ref := parameter_data.get('$ref', None):
-                parameter = self.parse_item_from_ref(parameter_id, ref)
+            if parameter_data.get('$ref', None):
+                parameter = self.parse_item_from_ref(parameter_id, parameter_data['$ref'])
             else:
                 parameter = self.parse_item(parameter_id, parameter_data)
             result[parameter_id] = parameter
@@ -27,10 +28,10 @@ class ParameterParser:
         resolved_ref = self._ref_resolver.resolve(ref)
         return self.parse_item(id_, resolved_ref.ref_data)
 
-    def parse_item(self, id_: str, data: dict[str, Any]) -> models.ParameterObject:
+    def parse_item(self, id_: str, data: Dict[str, Any]) -> models.ParameterObject:
         schema_data = data['schema']
-        if ref := schema_data.get('$ref', None):
-            resolved_ref = self._ref_resolver.resolve(ref)
+        if schema_data.get('$ref', None):
+            resolved_ref = self._ref_resolver.resolve(schema_data['$ref'])
             parsed_schema = self._schema_parser.parse_item(resolved_ref.ref_id, resolved_ref.ref_data)
         else:
             parsed_schema = self._schema_parser.parse_item(f'<inline+{models.SchemaObject.__name__}>', schema_data)
